# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Lobby Server."""

__version__ = "3.43.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_delete_global_config import AdminDeleteGlobalConfig
from .admin_get_global_config import AdminGetGlobalConfig
from .admin_update_global_config import AdminUpdateGlobalConfig
from .create_template import CreateTemplate
from .delete_template_localization import DeleteTemplateLocalization
from .delete_template_slug import DeleteTemplateSlug
from .free_form_notification import FreeFormNotification
from .get_game_template import GetGameTemplate
from .get_localization_template import GetLocalizationTemplate
from .get_slug_template import GetSlugTemplate
from .notification_with_template import NotificationWithTemplate
from .publish_template import PublishTemplate
from .update_localization_template import UpdateLocalizationTemplate
