# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Gdpr Service."""

__version__ = "2.24.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .s2s_generate_personal_data_url import S2SGeneratePersonalDataURL
from .s2s_get_data_request_by_21f4a4 import S2SGetDataRequestByRequestID
from .s2s_get_list_finished_p_06385b import S2SGetListFinishedPersonalDataRequest
from .s2s_request_data_retrieval import S2SRequestDataRetrieval
