# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ugc Service."""

__version__ = "2.28.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_approve_staging_content import AdminApproveStagingContent
from .admin_get_staging_conte_7fe68e import AdminGetStagingContentByID
from .admin_list_staging_contents import AdminListStagingContents
from .admin_list_user_staging_d2fe4e import AdminListUserStagingContents
