# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.34.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .delete_secret_v1 import DeleteSecretV1
from .delete_variable_v1 import DeleteVariableV1
from .get_list_of_secrets_v1 import GetListOfSecretsV1
from .get_list_of_variables_v1 import GetListOfVariablesV1
from .save_secret_v1 import SaveSecretV1
from .save_variable_v1 import SaveVariableV1
from .update_secret_v1 import UpdateSecretV1
from .update_variable_v1 import UpdateVariableV1
