# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApimodelCSMAppLimitsResponse
from ..models import ResponseErrorResponse

from ..operations.resources_limits import GetResourcesLimits


@same_doc_as(GetResourcesLimits)
def get_resources_limits(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Extend Apps Configurable Limits e.g. any kind of limits for front end validation use (GetResourcesLimits)

    This endpoint return the Extend Apps Configurable Limits for front end to use for initial validation before app creation
    e.g.
    Replica Limit will be used to check max replica that can be created for the said environment by default
    CPU Limit will be used to validate max allowed CPU for the extend app that hasn't been created
    Memory Limit will be used to validate max allowed Memory for the extend app that hasn't been created
    MaxAppNotificationSubscription will be used to validate the maximum number of subscriber for an app status notification

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/resources/limits

        method: GET

        tags: ["Resources Limits"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelCSMAppLimitsResponse

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        402: Payment Required - ResponseErrorResponse (Payment Required)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetResourcesLimits.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetResourcesLimits)
async def get_resources_limits_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get Extend Apps Configurable Limits e.g. any kind of limits for front end validation use (GetResourcesLimits)

    This endpoint return the Extend Apps Configurable Limits for front end to use for initial validation before app creation
    e.g.
    Replica Limit will be used to check max replica that can be created for the said environment by default
    CPU Limit will be used to validate max allowed CPU for the extend app that hasn't been created
    Memory Limit will be used to validate max allowed Memory for the extend app that hasn't been created
    MaxAppNotificationSubscription will be used to validate the maximum number of subscriber for an app status notification

    Properties:
        url: /csm/v2/admin/namespaces/{namespace}/resources/limits

        method: GET

        tags: ["Resources Limits"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelCSMAppLimitsResponse

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        402: Payment Required - ResponseErrorResponse (Payment Required)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetResourcesLimits.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
