# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.34.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_sql_cluster_v2 import CreateSQLClusterV2
from .create_sql_database_cre_9da946 import CreateSQLDatabaseCredentialV2
from .create_sql_database_v2 import CreateSQLDatabaseV2
from .delete_sql_cluster_v2 import DeleteSQLClusterV2
from .delete_sql_database_v2 import DeleteSQLDatabaseV2
from .get_sql_app_list_v2 import GetSQLAppListV2
from .get_sql_cluster_v2 import GetSQLClusterV2
from .get_sql_database_v2 import GetSQLDatabaseV2
from .start_sql_cluster_v2 import StartSQLClusterV2
from .stop_sql_cluster_v2 import StopSQLClusterV2
from .update_sql_cluster_v2 import UpdateSQLClusterV2
