# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "7.40.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_retrieve_user_thi_205ff1 import AdminRetrieveUserThirdPartyPlatformTokenV3
from .auth_code_request_v3 import AuthCodeRequestV3
from .authorize_v3 import AuthorizeV3
from .authorize_v3 import (
    CodeChallengeMethodEnum as AuthorizeV3CodeChallengeMethodEnum,
    ResponseTypeEnum as AuthorizeV3ResponseTypeEnum,
)
from .change2fa_method import Change2faMethod
from .get_authorization_serve_d0fc55 import GetAuthorizationServerMetadataWithNamespace
from .get_jwksv3 import GetJWKSV3
from .get_revocation_list_v3 import GetRevocationListV3
from .o_auth_dynamic_client_r_de5475 import OAuthDynamicClientRegisterWithNamespaceV3
from .platform_token_grant_v3 import PlatformTokenGrantV3
from .retrieve_user_third_par_204b6e import RetrieveUserThirdPartyPlatformTokenV3
from .revoke_user_v3 import RevokeUserV3
from .send_mfa_authentication_code import SendMFAAuthenticationCode
from .simultaneous_login_v3 import SimultaneousLoginV3
from .simultaneous_login_v3 import (
    NativePlatformEnum as SimultaneousLoginV3NativePlatformEnum,
)
from .token_grant_v3 import TokenGrantV3
from .token_grant_v3 import GrantTypeEnum as TokenGrantV3GrantTypeEnum
from .token_introspection_v3 import TokenIntrospectionV3
from .token_revocation_v3 import TokenRevocationV3
from .verify2fa_code import Verify2faCode
from .verify2fa_code_forward import Verify2faCodeForward
from .verify_token_v3 import VerifyTokenV3
