# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "6.14.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .delete_revocation_config import DeleteRevocationConfig
from .do_revocation import DoRevocation
from .get_revocation_config import GetRevocationConfig
from .query_revocation_histories import QueryRevocationHistories
from .query_revocation_histories import (
    SourceEnum as QueryRevocationHistoriesSourceEnum,
    StatusEnum as QueryRevocationHistoriesStatusEnum,
)
from .update_revocation_config import UpdateRevocationConfig
