# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "7.40.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_input_validations import AdminGetInputValidations
from .admin_get_namespace_sco_8a9f88 import AdminGetNamespaceScopedInputValidations
from .admin_reset_input_validations import AdminResetInputValidations
from .admin_reset_namespace_s_3f4c69 import AdminResetNamespaceScopedInputValidations
from .admin_update_input_validations import AdminUpdateInputValidations
from .admin_update_namespace__e9d7cc import AdminUpdateNamespaceScopedInputValidations
from .public_get_input_valida_e97ee4 import PublicGetInputValidationByField
from .public_get_input_validations import PublicGetInputValidations
from .public_get_namespace_sc_5faa32 import (
    PublicGetNamespaceScopedInputValidationByField,
)
from .public_get_namespace_sc_bb8236 import PublicGetNamespaceScopedInputValidations
