# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Login Queue Service."""

__version__ = "2.5.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# admin_v1
from .wrappers import admin_get_configuration
from .wrappers import admin_get_configuration_async
from .wrappers import admin_get_status
from .wrappers import admin_get_status_async
from .wrappers import admin_update_configuration
from .wrappers import admin_update_configuration_async

# ticket_v1
from .wrappers import cancel_ticket
from .wrappers import cancel_ticket_async
from .wrappers import refresh_ticket
from .wrappers import refresh_ticket_async
