# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Leaderboard Service."""

__version__ = "2.36.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_leaderboard_conf_2ad364 import CreateLeaderboardConfigurationAdminV3
from .delete_bulk_leaderboard_f7002d import DeleteBulkLeaderboardConfigurationAdminV3
from .delete_leaderboard_conf_8f143c import DeleteLeaderboardConfigurationAdminV3
from .get_leaderboard_configu_33150a import GetLeaderboardConfigurationAdminV3
from .get_leaderboard_configu_290af8 import GetLeaderboardConfigurationPublicV3
from .get_leaderboard_configu_9b2b53 import GetLeaderboardConfigurationsAdminV3
from .get_leaderboard_configu_b16dd3 import GetLeaderboardConfigurationsPublicV3
from .hard_delete_leaderboard_c58ff0 import HardDeleteLeaderboardAdminV3
from .update_leaderboard_conf_1b8e6b import UpdateLeaderboardConfigurationAdminV3
