# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Leaderboard Service."""

__version__ = "2.36.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._anonymization import admin_anonymize_user_leaderboard_admin_v1
from ._anonymization import admin_anonymize_user_leaderboard_admin_v1_async

from ._leaderboard_configuration import create_leaderboard_configuration_admin_v1
from ._leaderboard_configuration import create_leaderboard_configuration_admin_v1_async
from ._leaderboard_configuration import create_leaderboard_configuration_public_v1
from ._leaderboard_configuration import create_leaderboard_configuration_public_v1_async
from ._leaderboard_configuration import delete_bulk_leaderboard_configuration_admin_v1
from ._leaderboard_configuration import (
    delete_bulk_leaderboard_configuration_admin_v1_async,
)
from ._leaderboard_configuration import delete_leaderboard_configuration_admin_v1
from ._leaderboard_configuration import delete_leaderboard_configuration_admin_v1_async
from ._leaderboard_configuration import get_leaderboard_configuration_admin_v1
from ._leaderboard_configuration import get_leaderboard_configuration_admin_v1_async
from ._leaderboard_configuration import get_leaderboard_configurations_admin_v1
from ._leaderboard_configuration import get_leaderboard_configurations_admin_v1_async
from ._leaderboard_configuration import get_leaderboard_configurations_public_v1
from ._leaderboard_configuration import get_leaderboard_configurations_public_v1_async
from ._leaderboard_configuration import get_leaderboard_configurations_public_v2
from ._leaderboard_configuration import get_leaderboard_configurations_public_v2_async
from ._leaderboard_configuration import hard_delete_leaderboard_admin_v1
from ._leaderboard_configuration import hard_delete_leaderboard_admin_v1_async
from ._leaderboard_configuration import update_leaderboard_configuration_admin_v1
from ._leaderboard_configuration import update_leaderboard_configuration_admin_v1_async

from ._leaderboard_configuration_v3 import create_leaderboard_configuration_admin_v3
from ._leaderboard_configuration_v3 import (
    create_leaderboard_configuration_admin_v3_async,
)
from ._leaderboard_configuration_v3 import (
    delete_bulk_leaderboard_configuration_admin_v3,
)
from ._leaderboard_configuration_v3 import (
    delete_bulk_leaderboard_configuration_admin_v3_async,
)
from ._leaderboard_configuration_v3 import delete_leaderboard_configuration_admin_v3
from ._leaderboard_configuration_v3 import (
    delete_leaderboard_configuration_admin_v3_async,
)
from ._leaderboard_configuration_v3 import get_leaderboard_configuration_admin_v3
from ._leaderboard_configuration_v3 import get_leaderboard_configuration_admin_v3_async
from ._leaderboard_configuration_v3 import get_leaderboard_configuration_public_v3
from ._leaderboard_configuration_v3 import get_leaderboard_configuration_public_v3_async
from ._leaderboard_configuration_v3 import get_leaderboard_configurations_admin_v3
from ._leaderboard_configuration_v3 import get_leaderboard_configurations_admin_v3_async
from ._leaderboard_configuration_v3 import get_leaderboard_configurations_public_v3
from ._leaderboard_configuration_v3 import (
    get_leaderboard_configurations_public_v3_async,
)
from ._leaderboard_configuration_v3 import hard_delete_leaderboard_admin_v3
from ._leaderboard_configuration_v3 import hard_delete_leaderboard_admin_v3_async
from ._leaderboard_configuration_v3 import update_leaderboard_configuration_admin_v3
from ._leaderboard_configuration_v3 import (
    update_leaderboard_configuration_admin_v3_async,
)

from ._leaderboard_data import admin_get_archived_leaderboard_ranking_data_v1_handler
from ._leaderboard_data import (
    admin_get_archived_leaderboard_ranking_data_v1_handler_async,
)
from ._leaderboard_data import create_archived_leaderboard_ranking_data_v1_handler
from ._leaderboard_data import create_archived_leaderboard_ranking_data_v1_handler_async
from ._leaderboard_data import delete_user_ranking_admin_v1
from ._leaderboard_data import delete_user_ranking_admin_v1_async
from ._leaderboard_data import delete_user_ranking_by_leaderboard_code_admin_v1
from ._leaderboard_data import delete_user_ranking_by_leaderboard_code_admin_v1_async
from ._leaderboard_data import delete_user_ranking_public_v1
from ._leaderboard_data import delete_user_ranking_public_v1_async
from ._leaderboard_data import delete_user_rankings_admin_v1
from ._leaderboard_data import delete_user_rankings_admin_v1_async
from ._leaderboard_data import get_all_time_leaderboard_ranking_admin_v1
from ._leaderboard_data import get_all_time_leaderboard_ranking_admin_v1_async
from ._leaderboard_data import get_all_time_leaderboard_ranking_public_v1
from ._leaderboard_data import get_all_time_leaderboard_ranking_public_v1_async
from ._leaderboard_data import get_all_time_leaderboard_ranking_public_v2
from ._leaderboard_data import get_all_time_leaderboard_ranking_public_v2_async
from ._leaderboard_data import get_archived_leaderboard_ranking_data_v1_handler
from ._leaderboard_data import get_archived_leaderboard_ranking_data_v1_handler_async
from ._leaderboard_data import get_current_month_leaderboard_ranking_admin_v1
from ._leaderboard_data import get_current_month_leaderboard_ranking_admin_v1_async
from ._leaderboard_data import get_current_month_leaderboard_ranking_public_v1
from ._leaderboard_data import get_current_month_leaderboard_ranking_public_v1_async
from ._leaderboard_data import get_current_season_leaderboard_ranking_admin_v1
from ._leaderboard_data import get_current_season_leaderboard_ranking_admin_v1_async
from ._leaderboard_data import get_current_season_leaderboard_ranking_public_v1
from ._leaderboard_data import get_current_season_leaderboard_ranking_public_v1_async
from ._leaderboard_data import get_current_week_leaderboard_ranking_admin_v1
from ._leaderboard_data import get_current_week_leaderboard_ranking_admin_v1_async
from ._leaderboard_data import get_current_week_leaderboard_ranking_public_v1
from ._leaderboard_data import get_current_week_leaderboard_ranking_public_v1_async
from ._leaderboard_data import get_today_leaderboard_ranking_admin_v1
from ._leaderboard_data import get_today_leaderboard_ranking_admin_v1_async
from ._leaderboard_data import get_today_leaderboard_ranking_public_v1
from ._leaderboard_data import get_today_leaderboard_ranking_public_v1_async
from ._leaderboard_data import get_user_ranking_admin_v1
from ._leaderboard_data import get_user_ranking_admin_v1_async
from ._leaderboard_data import get_user_ranking_public_v1
from ._leaderboard_data import get_user_ranking_public_v1_async
from ._leaderboard_data import update_user_point_admin_v1
from ._leaderboard_data import update_user_point_admin_v1_async

from ._leaderboard_data_v3 import bulk_get_users_ranking_public_v3
from ._leaderboard_data_v3 import bulk_get_users_ranking_public_v3_async
from ._leaderboard_data_v3 import delete_all_user_ranking_by_cycle_id_admin_v3
from ._leaderboard_data_v3 import delete_all_user_ranking_by_cycle_id_admin_v3_async
from ._leaderboard_data_v3 import delete_user_ranking_admin_v3
from ._leaderboard_data_v3 import delete_user_ranking_admin_v3_async
from ._leaderboard_data_v3 import delete_user_ranking_by_cycle_id_admin_v3
from ._leaderboard_data_v3 import delete_user_ranking_by_cycle_id_admin_v3_async
from ._leaderboard_data_v3 import delete_user_ranking_by_leaderboard_code_admin_v3
from ._leaderboard_data_v3 import delete_user_ranking_by_leaderboard_code_admin_v3_async
from ._leaderboard_data_v3 import delete_user_rankings_admin_v3
from ._leaderboard_data_v3 import delete_user_rankings_admin_v3_async
from ._leaderboard_data_v3 import get_all_time_leaderboard_ranking_admin_v3
from ._leaderboard_data_v3 import get_all_time_leaderboard_ranking_admin_v3_async
from ._leaderboard_data_v3 import get_all_time_leaderboard_ranking_public_v3
from ._leaderboard_data_v3 import get_all_time_leaderboard_ranking_public_v3_async
from ._leaderboard_data_v3 import get_current_cycle_leaderboard_ranking_admin_v3
from ._leaderboard_data_v3 import get_current_cycle_leaderboard_ranking_admin_v3_async
from ._leaderboard_data_v3 import get_current_cycle_leaderboard_ranking_public_v3
from ._leaderboard_data_v3 import get_current_cycle_leaderboard_ranking_public_v3_async
from ._leaderboard_data_v3 import get_user_ranking_admin_v3
from ._leaderboard_data_v3 import get_user_ranking_admin_v3_async
from ._leaderboard_data_v3 import get_user_ranking_public_v3
from ._leaderboard_data_v3 import get_user_ranking_public_v3_async

from ._user_data import get_user_leaderboard_rankings_admin_v1
from ._user_data import get_user_leaderboard_rankings_admin_v1_async

from ._user_data_v3 import get_user_leaderboard_rankings_admin_v3
from ._user_data_v3 import get_user_leaderboard_rankings_admin_v3_async

from ._user_visibility import get_hidden_users_v2
from ._user_visibility import get_hidden_users_v2_async
from ._user_visibility import get_user_visibility_status_v2
from ._user_visibility import get_user_visibility_status_v2_async
from ._user_visibility import set_user_leaderboard_visibility_status_v2
from ._user_visibility import set_user_leaderboard_visibility_status_v2_async
from ._user_visibility import set_user_visibility_status_v2
from ._user_visibility import set_user_visibility_status_v2_async

from ._user_visibility_v3 import get_hidden_users_v3
from ._user_visibility_v3 import get_hidden_users_v3_async
from ._user_visibility_v3 import get_user_visibility_status_v3
from ._user_visibility_v3 import get_user_visibility_status_v3_async
from ._user_visibility_v3 import set_user_leaderboard_visibility_v3
from ._user_visibility_v3 import set_user_leaderboard_visibility_v3_async
from ._user_visibility_v3 import set_user_visibility_v3
from ._user_visibility_v3 import set_user_visibility_v3_async
