# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApimodelAppDebugInfoResponse
from ..models import ApimodelAppItem
from ..models import ApimodelUpdateDebugModeRequest
from ..models import ResponseErrorResponse

from ..operations.app_v4 import GetAppDebugInfoV4
from ..operations.app_v4 import UpdateAppDebugModeV4


@same_doc_as(GetAppDebugInfoV4)
def get_app_debug_info_v4(
    app: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get debug info for an extend app (GetAppDebugInfoV4)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:APP [READ]`

    Returns the list of debug-ready pods and exposed services for the given extend app.

    A pod is included only when it is in `Running` phase and has an
    `extend-proxy-sidecar` container.

    Properties:
        url: /csm/v4/admin/namespaces/{namespace}/apps/{app}/debuginfo

        method: GET

        tags: ["App V4"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelAppDebugInfoResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetAppDebugInfoV4.create(
        app=app,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetAppDebugInfoV4)
async def get_app_debug_info_v4_async(
    app: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get debug info for an extend app (GetAppDebugInfoV4)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:APP [READ]`

    Returns the list of debug-ready pods and exposed services for the given extend app.

    A pod is included only when it is in `Running` phase and has an
    `extend-proxy-sidecar` container.

    Properties:
        url: /csm/v4/admin/namespaces/{namespace}/apps/{app}/debuginfo

        method: GET

        tags: ["App V4"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelAppDebugInfoResponse (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = GetAppDebugInfoV4.create(
        app=app,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateAppDebugModeV4)
def update_app_debug_mode_v4(
    app: str,
    body: ApimodelUpdateDebugModeRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Enable or disable remote debug mode for an extend app (UpdateAppDebugModeV4)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:APP [UPDATE]`

    Enable or disable the remote debug sidecar container for the specified extend app.

    When enabled and the app is in `deployment-running` status, a new deployment will be
    triggered automatically to apply the debug container configuration.

    This operation is rejected with `409 Conflict` if the app is currently in a
    transitional state (app-creating, app-removing, app-stopping).

    Properties:
        url: /csm/v4/admin/namespaces/{namespace}/apps/{app}/debugmode

        method: PUT

        tags: ["App V4"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelUpdateDebugModeRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelAppItem (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateAppDebugModeV4.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateAppDebugModeV4)
async def update_app_debug_mode_v4_async(
    app: str,
    body: ApimodelUpdateDebugModeRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Enable or disable remote debug mode for an extend app (UpdateAppDebugModeV4)

    Required permission : `ADMIN:NAMESPACE:{namespace}:EXTEND:APP [UPDATE]`

    Enable or disable the remote debug sidecar container for the specified extend app.

    When enabled and the app is in `deployment-running` status, a new deployment will be
    triggered automatically to apply the debug container configuration.

    This operation is rejected with `409 Conflict` if the app is currently in a
    transitional state (app-creating, app-removing, app-stopping).

    Properties:
        url: /csm/v4/admin/namespaces/{namespace}/apps/{app}/debugmode

        method: PUT

        tags: ["App V4"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApimodelUpdateDebugModeRequest in body

        app: (app) REQUIRED str in path

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApimodelAppItem (OK)

        400: Bad Request - ResponseErrorResponse (Bad Request)

        401: Unauthorized - ResponseErrorResponse (Unauthorized)

        403: Forbidden - ResponseErrorResponse (Forbidden)

        404: Not Found - ResponseErrorResponse (Not Found)

        409: Conflict - ResponseErrorResponse (Conflict)

        500: Internal Server Error - ResponseErrorResponse (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace(sdk=kwargs.get("sdk"))
        if error:
            return None, error
    request = UpdateAppDebugModeV4.create(
        app=app,
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
