# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Gdpr Service."""

__version__ = "2.24.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .dto_extend_config_dto import DtoExtendConfigDTO
from .dto_finished_data_deletion import DtoFinishedDataDeletion
from .dto_finished_data_deletion import StatusEnum as DtoFinishedDataDeletionStatusEnum
from .dto_finished_data_request import DtoFinishedDataRequest
from .dto_finished_data_request import StatusEnum as DtoFinishedDataRequestStatusEnum
from .dto_list_finished_data_deletion import DtoListFinishedDataDeletion
from .dto_list_finished_data_requests import DtoListFinishedDataRequests
from .dto_platform_account_closure_client_request import (
    DtoPlatformAccountClosureClientRequest,
)
from .dto_platform_account_closure_client_response import (
    DtoPlatformAccountClosureClientResponse,
)
from .dto_platform_account_closure_clients_response import (
    DtoPlatformAccountClosureClientsResponse,
)
from .dto_platform_account_closure_mock_request import (
    DtoPlatformAccountClosureMockRequest,
)
from .dto_s2s_data_request_summary import DtoS2SDataRequestSummary
from .dto_s2s_data_request_summary import (
    StatusEnum as DtoS2SDataRequestSummaryStatusEnum,
)
from .dto_service_config_dto import DtoServiceConfigDTO
from .dto_service_config_dto import ProtocolEnum as DtoServiceConfigDTOProtocolEnum
from .dto_service_configuration_dto import DtoServiceConfigurationDTO
from .dto_service_configuration_dto import (
    TypeEnum as DtoServiceConfigurationDTOTypeEnum,
)
from .dto_service_configuration_update_request import (
    DtoServiceConfigurationUpdateRequest,
)
from .dto_services_configuration_response import DtoServicesConfigurationResponse
from .dto_user_platform_account_closure_histories_response import (
    DtoUserPlatformAccountClosureHistoriesResponse,
)
from .dto_user_platform_account_closure_history import (
    DtoUserPlatformAccountClosureHistory,
)
from .dto_xbox_bp_cert_validation_request import DtoXboxBPCertValidationRequest
from .dto_xbox_bp_cert_validation_response import DtoXboxBPCertValidationResponse
from .models_data_retrieval_response import ModelsDataRetrievalResponse
from .models_deletion_data import ModelsDeletionData
from .models_deletion_status import ModelsDeletionStatus
from .models_list_deletion_data_response import ModelsListDeletionDataResponse
from .models_list_personal_data_response import ModelsListPersonalDataResponse
from .models_pagination import ModelsPagination
from .models_personal_data import ModelsPersonalData
from .models_request_delete_response import ModelsRequestDeleteResponse
from .models_s2s_data_retrieval_response import ModelsS2SDataRetrievalResponse
from .models_s2s_request_delete_response import ModelsS2SRequestDeleteResponse
from .models_s2s_user_data_url import ModelsS2SUserDataURL
from .models_user_data_url import ModelsUserDataURL
from .models_user_personal_data import ModelsUserPersonalData
from .models_user_personal_data_response import ModelsUserPersonalDataResponse
from .response_error import ResponseError
