# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.32.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .bulk_get_my_binary_record_v1 import BulkGetMyBinaryRecordV1
from .bulk_get_other_player_p_6c2093 import BulkGetOtherPlayerPublicBinaryRecordsV1
from .bulk_get_player_public__6635d7 import BulkGetPlayerPublicBinaryRecordsV1
from .delete_player_binary_record_v1 import DeletePlayerBinaryRecordV1
from .get_player_binary_record_v1 import GetPlayerBinaryRecordV1
from .get_player_public_binar_e2a2d6 import GetPlayerPublicBinaryRecordsV1
from .list_my_binary_records_v1 import ListMyBinaryRecordsV1
from .list_other_player_publi_a9eef5 import ListOtherPlayerPublicBinaryRecordsV1
from .post_player_binary_pres_38c5b5 import PostPlayerBinaryPresignedURLV1
from .post_player_binary_record_v1 import PostPlayerBinaryRecordV1
from .put_player_binary_recor_012bcd import PutPlayerBinaryRecorMetadataV1
from .put_player_binary_record_v1 import PutPlayerBinaryRecordV1
