# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Gdpr Service."""

__version__ = "2.24.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .public_cancel_my_person_702fb0 import PublicCancelMyPersonalDataRequest
from .public_generate_my_head_3818b6 import PublicGenerateMyHeadlessPersonalDataURL
from .public_get_my_personal__1068bc import PublicGetMyPersonalDataRequests
from .public_submit_my_headle_42af28 import PublicSubmitMyHeadlessPersonalDataRequest
from .public_submit_my_person_811b35 import PublicSubmitMyPersonalDataRequest
