# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Custom Service Manager."""

__version__ = "1.34.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_key_value_cluster_v2 import CreateKeyValueClusterV2
from .create_key_value_credential_v2 import CreateKeyValueCredentialV2
from .delete_key_value_cluster_v2 import DeleteKeyValueClusterV2
from .get_integration_app_key_181476 import GetIntegrationAppKeyValueClusterV2
from .get_key_value_cluster_l_62a4fb import GetKeyValueClusterLimitConfigV2
from .get_key_value_cluster_v2 import GetKeyValueClusterV2
from .get_list_integrated_app_4a9d12 import GetListIntegratedAppKeyValueClusterV2
from .integrate_app_key_value_d23a27 import IntegrateAppKeyValueClusterV2
from .list_key_value_cluster_v2 import ListKeyValueClusterV2
from .remove_integration_app__84d881 import RemoveIntegrationAppKeyValueClusterV2
from .update_key_value_cluster_v2 import UpdateKeyValueClusterV2
