# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "4.9.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .old_create_localized_po_27ca82 import OldCreateLocalizedPolicyVersion
from .old_public_retrieve_sin_4e7606 import (
    OldPublicRetrieveSingleLocalizedPolicyVersion,
)
from .old_request_presigned_url import OldRequestPresignedURL
from .old_retrieve_localized__18cbb5 import OldRetrieveLocalizedPolicyVersions
from .old_retrieve_single_loc_881bb2 import OldRetrieveSingleLocalizedPolicyVersion
from .old_set_default_localiz_e3b777 import OldSetDefaultLocalizedPolicy
from .old_update_localized_po_4765cb import OldUpdateLocalizedPolicyVersion
