# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "4.9.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .accept_versioned_policy import AcceptVersionedPolicy
from .bulk_accept_versioned_policy import BulkAcceptVersionedPolicy
from .change_preference_consent import ChangePreferenceConsent
from .indirect_bulk_accept_ve_34e753 import IndirectBulkAcceptVersionedPolicyV2
from .old_retrieve_accepted_a_36c88d import OldRetrieveAcceptedAgreements
from .old_retrieve_all_users__abe0f3 import OldRetrieveAllUsersByPolicyVersion
from .public_change_preferenc_69bf81 import PublicChangePreferenceConsent
from .public_indirect_bulk_ac_42b465 import PublicIndirectBulkAcceptVersionedPolicy
from .retrieve_agreements_public import RetrieveAgreementsPublic
